*$ CREATE FLDSCP.FOR
*COPY FLDSCP
*
*=== Fldscp ===========================================================*
*
      SUBROUTINE FLDSCP ( IJ    , PLA   , TXX   , TYY   , TZZ   ,
     &                    NTRUCK, XTRUCK, YTRUCK, ZTRUCK, NREG  ,
     &                    IOLREG, LLO   , ICALL )

      INCLUDE '(DBLPRC)'
      INCLUDE '(DIMPAR)'
      INCLUDE '(IOUNIT)'
*
*----------------------------------------------------------------------*
*                                                                      *
*     Copyright (C) 2001-2005      by    Alfredo Ferrari & Paola Sala  *
*     All Rights Reserved.                                             *
*                                                                      *
*                                                                      *
*     FLuence DiStributed - Change of Positions                        *
*                                                                      *
*     Created on   13 april 2001   by    Alfredo Ferrari & Paola Sala  *
*                                                                      *
*     Last change on 13-apr-01     by    Alfredo Ferrari               *
*                                                                      *
*     Input variables:                                                 *
*                                                                      *
*                   Ij = (generalized) particle code                   *
*                  Pla = particle momentum (if > 0), or kinetic        *
*                        energy (if <0 )                               *
*            Txx,yy,zz = particle direction cosines                    *
* X,Y,Ztruck(0:Ntruck) = particle step points                          *
*                 Nreg = (new) region number                           *
*               Iolreg = (old) region number                           *
*                  Llo = particle generation                           *
*                Icall = call id.                                      *
*                                                                      *
*     Output variables:                                                *
*                                                                      *
* X,Y,Ztruck(0:Ntruck) = particle step points                          *
*                                                                      *
*     Useful variables (common SCOHLP):                                *
*                                                                      *
*     Flux like binnings/estimators:                                   *
*          ISCRNG = 1 --> Boundary crossing estimator                  *
*          ISCRNG = 2 --> Track  length     binning                    *
*          ISCRNG = 3 --> Track  length     estimator                  *
*          ISCRNG = 4 --> Collision density estimator                  *
*          ISCRNG = 5 --> Yield             estimator                  *
*          JSCRNG = # of the binning/estimator                         *
*                                                                      *
*----------------------------------------------------------------------*
*
      INCLUDE '(SCOHLP)'
*
      DIMENSION XTRUCK (0:NTRUCK), YTRUCK (0:NTRUCK), ZTRUCK (0:NTRUCK)
*
      RETURN
*=== End of subroutine Fldscp =========================================*
      END

